@@ -27,6 +27,12 @@ class S3:
 		self._root = root
 		self._spark = spark
 
+		self.list = self.ls
+		self.move = self.mv
+		self.dir = self.ls
+		self.copy = self.cp
+		self.delete = self.rm
+
 	@property
 	def file_system(self):
 		return S3FileSystem(key=self._key, secret=self._secret, use_ssl=False)
@@ -55,6 +61,20 @@ class S3:
 				files.sort()
 		return files
 
+	def mv(self, path1, path2, recursive=True, max_depth=None, **kwargs):
+		return self.file_system.mv(path1=path1, path2=path2, recursive=recursive, maxdepth=max_depth, **kwargs)
+
+	def cp(self, path1, path2, recursive=True, on_error=None, **kwargs):
+		return self.file_system.copy(path1=path1, path2=path2, recursive=recursive, on_error=on_error, **kwargs)
+
+	def rm(self, path, recursive=True, **kwargs):
+		path = self._get_absolute_path(path)
+		return self.file_system.delete(path=path, recursive=recursive, **kwargs)
+
+	def mkdir(self, path, **kwargs):
+		path = self._get_absolute_path(path)
+		return self.file_system.mkdir(path=path, **kwargs)
+
 	def tree(self, path, depth_limit=None, indentation='\t'):
 		def _get_tree(_path, _depth):
 			subs = self.ls(_path)
@@ -82,18 +102,6 @@ class S3:
 		path = self._get_absolute_path(path)
 		return self.file_system.exists(path=path)
 
-	def delete(self, path, recursive=False):
-		path = self._get_absolute_path(path)
-		return self.file_system.delete(path=path, recursive=recursive)
-
-	def mkdir(self, path, **kwargs):
-		path = self._get_absolute_path(path)
-		return self.file_system.mkdir(path=path, **kwargs)
-
-	def rm(self, path, **kwargs):
-		path = self._get_absolute_path(path)
-		return self.file_system.rm(path=path, **kwargs)
-
 	def write(self, path, bytes):
 		path = self._get_absolute_path(path)
 		with self.file_system.open(path=path, mode='wb') as f:
@@ -188,7 +196,7 @@ class S3:
 		path = self._get_absolute_path(path)
 
 		if mode == 'overwrite':
-			self.delete(path=path)
+			self.rm(path=path)
 
 		data.write.mode(mode).save(path=path)
 		return self.ls(path=path)
@@ -233,6 +241,16 @@ class S3:
 		else:
 			return None
 
+	def is_file(self, path):
+		return self.file_system.isfile(path=path)
+
+	def is_dir(self, path):
+		return self.file_system.isdir(path)
+
+	@property
+	def json(self):
+		return self.file_system.to_json()
+
 	def is_parquet_file(self, path):
 		"""
 		returns True if a path is a parquet file
